Tutorials — Python reimplementation of NIXIO (http://g-node.github.io/nix/) 1.5.0 Development documentation

# Tutorials

This introduction guides through the NIX data model and shows how to use it with the nixio python library.

In the following we provide an introduction to the general concepts of the NIX data model, try to illustrate its design principles and provide code examples showing the usage of the python library for reading and writing NIX files.

Code examples use the python library but almost all functions have direct counterparts also in the C++ library or the language bindings to this for Matlab and java.

## List of tutorials

Most code examples are standalone and you should be able to run them. The code is also available from the project repository on GitHub.

- File handling
- Storing data
- Tagging points and regions
- Handling of units
- Working with data
- Annotations with arbitrary metadata
- Noting the origin of data
- Finding things
- Image data
- Spike time data